@@ -15,9 +15,9 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: AlbumItem.php,v 1.94.2.4 2005/04/14 01:48:29 cryptographite Exp $
+ * $Id: AlbumItem.php,v 1.102.2.1 2005/09/12 22:40:44 dmolavi Exp $
  */
 ?>
 <?php
@@ -493,17 +493,14 @@ class AlbumItem {
         function watermark($dir, $wmName, $wmAlphaName, $wmAlign, $wmAlignX, $wmAlignY, $preview=0, $previewSize=0, $wmSelect=0) {
                 global $gallery;
                 $type = $this->image->type;
-		if (isMovie($type) || $this->isAlbum())
-		{
+		if (isMovie($type) || $this->isAlbum()) {
 			// currently there is no watermarking support for movies
 			return (0);
 		}
-		if ($wmSelect < 0)
-		{
+		if ($wmSelect < 0) {
 			$wmSelect = 0;
 		}
-		else if ($wmSelect > 2)
-		{
+		else if ($wmSelect > 2) {
 			$wmSelect = 2;
 		}
                 $name = $this->image->name;
@@ -652,6 +649,8 @@ class AlbumItem {
 	}
 
 	function getThumbnailTag($dir, $size=0, $attrs="") {
+		// Prevent non-integer data from being passed
+		$size = (int)$size;
 
 		if ($this->thumbnail) {
 			return $this->thumbnail->getTag($dir, 0, $size, $attrs, $this->getAlttext());
@@ -661,6 +660,8 @@ class AlbumItem {
 	}
 
 	function getHighlightTag($dir, $size=0, $attrs='', $alttext='') {
+		// Prevent non-integer data from being passed
+		$size = (int)$size;
 
 		if (is_object($this->highlightImage)) {
 			if (!isset($alttext)) {
@@ -673,9 +674,9 @@ class AlbumItem {
 		}
 	}
 
-	function getPhotoTag($dir, $full=0) {
+	function getPhotoTag($dir, $full=0, $attrs) {
 		if ($this->image) {
-			return $this->image->getTag($dir, $full, '', '', $this->getAlttext());
+			return $this->image->getTag($dir, $full, '', $attrs, $this->getAlttext());
 		} else {
 			return "about:blank";
 		}
