@@ -15,9 +15,9 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: gallery_remote2.php,v 1.70.2.2 2005/04/14 01:48:23 cryptographite Exp $
+ * $Id: gallery_remote2.php,v 1.75.2.2 2005/09/12 22:40:44 dmolavi Exp $
  */
 ?>
 <?php
@@ -35,7 +35,6 @@ if (!getRequestVar('cmd')) {
 	exit;
 }
 
-
 /*
  * Set content type
  */
@@ -44,7 +43,7 @@ header("Content-type: text/plain");
 /*
  * Start buffering output
  */
-//if($gallery->app->debug == "no") {
+//if(!isDebugging()) {
 //	@ob_start();
 //}
 
@@ -82,8 +81,6 @@ $GR_STAT['MOVE_ALBUM_FAILED']	= 503;
 $GR_STAT['ROTATE_IMAGE_FAILED'] = 504;
 
 
-
-
 $response = new Properties();
 $protocol_version = getRequestVar('protocol_version');
 check_proto_version( $response );
@@ -142,7 +139,7 @@ echo $response->listprops();
 
 
 
-function gr_login( &$gallery, &$response, &$uname, &$password ) {
+function gr_login( &$gallery, &$response, $uname, $password ) {
 	global $GR_STAT, $GR_VER;
 
 	if (!$uname | !$password) {
@@ -241,7 +238,7 @@ function gr_fetch_albums_prune( &$gallery, &$response, $check_writeable ) {
 
 }
 
-function gr_add_item( &$gallery, &$response, &$userfile, &$userfile_name, &$caption, &$force_filename, &$auto_rotate ) {
+function gr_add_item( &$gallery, &$response, &$userfile, &$userfile_name, $caption, $force_filename, $auto_rotate ) {
 
 	global $GR_STAT, $temp_files;
 
@@ -336,9 +333,6 @@ function gr_album_properties( &$gallery, &$response ) {
 	global $GR_STAT;
 
 	$resize_dimension = $gallery->album->fields['resize_size'];
-	if ($resize_dimension == 'off') {
-		$resize_dimension = 0;
-	}
 
 	$response->setProperty( 'auto_resize', $resize_dimension );
 
@@ -361,16 +355,10 @@ function gr_album_properties( &$gallery, &$response ) {
 
 }
 
-function gr_new_album( &$gallery, &$response, &$newAlbumName, &$newAlbumTitle, &$newAlbumDesc ) {
+function gr_new_album( &$gallery, &$response, $newAlbumName, $newAlbumTitle, $newAlbumDesc ) {
 
 	global $GR_STAT;
 
-	if(get_magic_quotes_gpc()) {
-		$newAlbumName = stripslashes($newAlbumName);
-		$newAlbumTitle = stripslashes($newAlbumTitle);
-		$newAlbumDesc = stripslashes($newAlbumDesc);
-	}
-
 	if(isset($gallery->album) && isset($gallery->album->fields["name"])) {
 		$canAddAlbum = $gallery->user->canCreateSubAlbum($gallery->album);
 	} else {
@@ -452,7 +440,7 @@ function gr_fetch_album_images( &$gallery, &$response, $albums_too ) {
 					$response->setProperty( 'image.capturedate.hours.'.$tmpImageNum, $albumItemObj->itemCaptureDate['hours'] );
 					$response->setProperty( 'image.capturedate.minutes.'.$tmpImageNum, $albumItemObj->itemCaptureDate['minutes'] );
 					$response->setProperty( 'image.capturedate.seconds.'.$tmpImageNum, $albumItemObj->itemCaptureDate['seconds'] );
-					$response->setProperty( 'image.hidden.'.$tmpImageNum, $albumItemObj->isHidden()?"yes":"no" );
+					$response->setProperty( 'image.hidden.'.$tmpImageNum, $albumItemObj->isHidden()? "yes":"no" );
 				} else {
 					if ($albums_too) {
 						if (! isset($albumDB)) {
@@ -465,7 +453,7 @@ function gr_fetch_album_images( &$gallery, &$response, $albums_too ) {
 							$tmpImageNum++;
 
 							$response->setProperty( 'album.name.'.$tmpImageNum, $albumItemObj->getAlbumName() );
-							$response->setProperty( 'album.hidden.'.$tmpImageNum, $myAlbum->isHiddenRecurse()?'yes':'no' );
+							$response->setProperty( 'album.hidden.'.$tmpImageNum, $myAlbum->isHiddenRecurse() ? 'yes':'no' );
 						}
 					}
 				}
@@ -665,8 +653,6 @@ function gr_rotate_image( &$gallery, &$response ) {
 }
 */
 
-
-
 function check_proto_version( &$response ) {
 	global $protocol_version, $GR_STAT, $GR_VER;
 
@@ -767,8 +753,8 @@ function add_album( &$myAlbum, &$album_index, $parent_index, &$response ){
 	$response->setProperty( "album.title.$album_index", $albumTitle );
 	$response->setProperty( "album.summary.$album_index", $myAlbum->fields['summary'] );
 	$response->setProperty( "album.parent.$album_index", $parent_index );
-	$response->setProperty( "album.resize_size.$album_index", $myAlbum->fields['resize_size'] == 'off' ? 0 : $myAlbum->fields['resize_size'] );
-	$response->setProperty( "album.max_size.$album_index", $myAlbum->fields['max_size'] == 'off' ? 0 : $myAlbum->fields['max_size'] );
+	$response->setProperty( "album.resize_size.$album_index", $myAlbum->fields['resize_size'] );
+	$response->setProperty( "album.max_size.$album_index", $myAlbum->fields['max_size'] );
 	$response->setProperty( "album.thumb_size.$album_index", $myAlbum->fields['thumb_size'] );
 
 	// write permissions
@@ -837,9 +823,7 @@ function processFile($file, $tag, $name, $setCaption="") {
     } else {
         // remove %20 and the like from name
         $name = urldecode($name);
-	if (get_magic_quotes_gpc()) {
-		$name = stripslashes($name);
-	}
+
         // parse out original filename without extension
         $originalFilename = eregi_replace(".$tag$", "", $name);
         // replace multiple non-word characters with a single "_"
@@ -880,9 +864,6 @@ function processFile($file, $tag, $name, $setCaption="") {
 		    }
 
             if ($setCaption) {
-		if (get_magic_quotes_gpc()) {
-			$setCaption = stripslashes($setCaption);
-		}
                 $caption = $setCaption;
             } else {
                 $caption = "";
@@ -895,23 +876,17 @@ function processFile($file, $tag, $name, $setCaption="") {
 				//echo "Looking for extra field $fieldname\n";
 
 				// The way it should be done now
-				$value = isset($_POST[("extrafield.".$field)]) ? $_POST[("extrafield.".$field)] : '';
+				$value = getRequestVar("extrafield.".$field);
 				//echo "Got extra field $field = $value\n";
-				if ($value) {
-					if (get_magic_quotes_gpc()) {
-						$value = stripslashes($value);
-					}
+				if (!empty($value)) {
 					//echo "Setting field $field\n";
 					$myExtraFields[$field] = $value;
 				}
 
 				// Deprecated
-				$value = isset($_POST[("extrafield_".$field)]) ? $_POST[("extrafield_".$field)] : '';
+				$value = getRequestVar("extrafield_".$field);
 				//echo "Got extra field $field = $value\n";
-				if ($value) {
-					if (get_magic_quotes_gpc()) {
-						$value = stripslashes($value);
-					}
+				if (!empty($value)) {
 					//echo "Setting field $field\n";
 					$myExtraFields[$field] = $value;
 				}
