@@ -15,31 +15,38 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: gl_ES-nls.php,v 1.4.2.3 2005/03/23 08:54:34 cryptographite Exp $
- *
- * Version: 1.5
+ * $Id: gl_ES-nls.php,v 1.8.2.2 2005/09/12 22:40:56 dmolavi Exp $
  */
+ 
+/**
+ * @version	1.5.1
+ * @package	Languagepack
+ * @subpackage	Galego
+ */
+
 /**
  * NLS (National Language System) array.
  *
  * The basic idea and values was taken from then Horde Framework (http://horde.org)
  * The original filename was horde/config/nls.php.dist.
- * The modifications to fit it for Gallery were made by Jens Tkotz 
+ * The modifications to fit it for Gallery were made by Jens Tkotz.
  * (jens@peino.de)
- *
  */
 
-
 /**
- ** Native languagename
- **/
+ * Native languagename
+ */
 	$nls['language']['gl_ES'] = 		'Galego';
 
 /**
- ** Aliases for languages with different browser and gettext codes
- **/
-
+ * Aliases for languages with different browser and gettext codes
+ */
 	$nls['alias']['gl'] = 			'gl_Es';
+
+/**
+ * Aliases for languages which we substitte or send by Mambo
+ */
+	$nls['alias']['Galician'] =		'gl_ES' ;
 ?>
