@@ -15,15 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: phpinfo.php,v 1.9.6.1 2005/03/10 02:36:35 cryptographite Exp $
+ * $Id: phpinfo.php,v 1.10.2.2 2005/09/12 22:41:29 dmolavi Exp $
  */
 ?>
 <?php
-	/* load necessary functions */
-	require (dirname(__FILE__) . '/init.php');	
-	require (GALLERY_SETUPDIR . '/functions.inc');
-	configLogin(basename(__FILE__));
-	phpinfo(); 
+    /* load necessary functions */
+    require (dirname(__FILE__) . '/init.php');	
+    configLogin(basename(__FILE__));
+    phpinfo(); 
 ?>
